# Onzr

The one-hour-late Deezer 💜 CLI.

> :warning: This project is a work in progress. It works in its core parts, but
> will not meet standard requirements for a decent player.

## Requirements

- [VLC](https://www.videolan.org/vlc/index.en_GB.html): we use VLC bindings to
  play tracks, so this is a strict requirement.

## Quick start guide (for developers)

Install dependencies in a working environment:

```sh
make bootstrap
```

Run linters:

```sh
make lint
```

Run tests:

```sh
make test
```

## License

This work is released under the MIT License.
